@@ -3,15 +3,15 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-use crate::transform::utils::*;
+use crate::transform::utils::{rust_code_block_iterator, ItemOrOther};
 use crate::transform::DocTransform;
 use crate::Doc;
-use itertools::Itertools;
 use std::convert::Infallible;
 
 pub struct DocTransformRustRemoveComments;
 
 impl DocTransformRustRemoveComments {
+    #[must_use]
     pub fn new() -> DocTransformRustRemoveComments {
         DocTransformRustRemoveComments
     }
@@ -24,12 +24,12 @@ fn is_line_commented(line: &str) -> bool {
 fn process_code_block(new_doc_str: &mut String, code_block: &str) {
     let mut first = true;
 
-    for (i, line) in code_block.split("\n").enumerate() {
+    for (i, line) in code_block.split('\n').enumerate() {
         // If we have an indent code block and we start with a comment we need to
         // drop any indent whitespace that started this indent block, since
         // pulldown-cmark doesn't consider it part of the code block.
         if i == 0 && is_line_commented(line) {
-            while !new_doc_str.ends_with("\n") && !new_doc_str.is_empty() {
+            while !new_doc_str.ends_with('\n') && !new_doc_str.is_empty() {
                 new_doc_str.pop();
             }
         }
@@ -55,10 +55,9 @@ impl DocTransform for DocTransformRustRemoveComments {
     type E = Infallible;
 
     fn transform(&self, doc: &Doc) -> Result<Doc, Infallible> {
-        let source = doc.lines().join("\n");
         let mut new_doc_str = String::new();
 
-        for item_or_other in rust_code_block_iterator(&source).complete() {
+        for item_or_other in rust_code_block_iterator(&doc.markdown).complete() {
             match item_or_other {
                 ItemOrOther::Item(code_block) => {
                     process_code_block(&mut new_doc_str, code_block);
@@ -547,4 +546,42 @@ mod tests {
             assert_eq!(transform.transform(&doc).unwrap(), doc);
         }
     }
+
+    #[test]
+    fn test_remove_comments_nested_fenced_block() {
+        let doc_str = indoc! { r#"
+            ````
+            # Comment 1
+            let s = "
+            ```
+            ";
+            # Comment 2
+            println!("Hi");
+            let s = "
+            ```
+            ";
+            ````
+            "#
+        };
+
+        let expected_str = indoc! { r#"
+            ````
+            let s = "
+            ```
+            ";
+            println!("Hi");
+            let s = "
+            ```
+            ";
+            ````
+            "#
+        };
+
+        let doc = Doc::from_str(doc_str);
+        let expected = Doc::from_str(expected_str);
+
+        let transform = DocTransformRustRemoveComments::new();
+
+        assert_eq!(transform.transform(&doc).unwrap(), expected);
+    }
 }
